@@ -4,19 +4,26 @@ package Business::CreditCard;
 #
 # Jon Orwant, <orwant@media.mit.edu>
 #
-# 12 July 96
+# 12 Jul 96 - created
+# 17 Jan 97 - 0.21 released.
+#             short numbers and numbers with letters are no longer kosher.
+# 1 Feb 2001 - 0.22 released, new maintainer, MakeMaker installation
 #
-# Copyright 1995 Jon Orwant.  All rights reserved.
+# Copyright 1995,1996,1997 Jon Orwant.  All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # 
-# Version 0.1.  Module list status is "Rdpf."
+# Version 0.22.  Module list status is "Rdpf."
 
 require 5;
 
 require Exporter;
+use vars qw( @ISA $VERSION );
+
 @ISA = qw( Exporter );
 
+$VERSION = "0.22";
+
 =head1 NAME
 
 C<Business::CreditCard> - Validate/generate credit card checksums/names
@@ -52,7 +59,7 @@ This module does I<not> tell you whether the number is on an actual
 card, only whether it might conceivably be on a real card.  To verify
 whether a card is real, or whether it's been stolen, or what its
 balance is, you need a Merchant ID, which gives you access to credit
-card databases.  The Perl Journal (http://work.media.mit.edu/tpj) has
+card databases.  The Perl Journal (http://tpj.com/tpj) has
 a Merchant ID so that I can accept MasterCard and VISA payments; it
 comes with the little pushbutton/slide-your-card-through device you've
 seen in restaurants and stores.  That device calculates the checksum
@@ -61,18 +68,16 @@ for you, so I don't actually use this module.
 These subroutines will also work if you provide the arguments
 as numbers instead of strings, e.g. C<validate(5276440065421319)>.  
 
-To install this module, change directories to wherever
-your system keeps Perl modules (e.g. C</usr/local/lib/perl5>) and
-create a C<Business> directory if there's isn't one already.
-Then copy this file there.  That's it!
-
 =head1 AUTHOR
 
 Jon Orwant
 
-MIT Media Lab
+The Perl Journal and MIT Media Lab
 
-orwant@media.mit.edu
+orwant@tpj.com
+
+Current maintainer is Ivan Kohler <ivan-business-creditcard@420.am>.
+Please don't bother Jon with emails about this module.
 
 =cut
 
@@ -81,8 +86,12 @@ orwant@media.mit.edu
 sub cardtype {
     my ($number) = @_;
 
+    return "Not a credit card" if $number =~ /[^\d\s]/;
+
     $number =~ s/\D//g;
 
+    return "Not a credit card" unless length($number) >= 13 && 0+$number;
+
     return "VISA card" if substr($number,0,1) == "4";
     return "MasterCard" if substr($number,0,1) == "5";
     return "Discover card" if substr($number,0,1) == "6";
@@ -108,9 +117,13 @@ sub generate_last_digit {
 sub validate {
     my ($number) = @_;
     my ($i, $sum, $weight);
+    
+    return 0 if $number =~ /[^\d\s]/;
 
     $number =~ s/\D//g;
 
+    return 0 unless length($number) >= 13 && 0+$number;
+
     for ($i = 0; $i < length($number) - 1; $i++) {
 	$weight = substr($number, -1 * ($i + 2), 1) * (2 - ($i % 2));
 	$sum += (($weight < 10) ? $weight : ($weight - 9));
